.. module:: pywayland.server

.. _server:

Server Modules
==============

The base set of objects used by Wayland servers.

Client
------

.. autoclass:: Client
   :members:

Display
-------

.. autoclass:: Display
   :members:

EventLoop
---------

.. autoclass:: EventLoop
   :members:

Listener
--------

.. autoclass:: Listener
   :members:
